@@ -15,7 +15,7 @@ from . import transformations as tf
 from .base import Trimesh
 from .constants import log, tol
 from .geometry import align_vectors, faces_to_edges, plane_transform
-from .typed import ArrayLike, Dict, NDArray, Optional, float64
+from .typed import ArrayLike, Dict, Integer, Number, Optional
 
 try:
     # shapely is a soft dependency
@@ -35,11 +35,11 @@ except BaseException as E:
 
 def revolve(
     linestring: ArrayLike,
-    angle: Optional[float] = None,
-    sections: Optional[int] = None,
-    transform: Optional[NDArray] = None,
+    angle: Optional[Number] = None,
+    sections: Optional[Integer] = None,
+    transform: Optional[ArrayLike] = None,
     **kwargs,
-):
+) -> Trimesh:
     """
     Revolve a 2D line string around the 2D Y axis, with a result with
     the 2D Y axis pointing along the 3D Z axis.
@@ -173,8 +173,8 @@ def revolve(
 
 
 def extrude_polygon(
-    polygon: "Polygon", height: float, transform: Optional[NDArray] = None, **kwargs
-):
+    polygon: "Polygon", height: Number, transform: Optional[ArrayLike] = None, **kwargs
+) -> Trimesh:
     """
     Extrude a 2D shapely polygon into a 3D mesh
 
@@ -206,7 +206,7 @@ def extrude_polygon(
 
 
 def sweep_polygon(
-    polygon: "Polygon", path: ArrayLike, angles: Optional[NDArray] = None, **kwargs
+    polygon: "Polygon", path: ArrayLike, angles: Optional[ArrayLike] = None, **kwargs
 ):
     """
     Extrude a 2D shapely polygon into a 3D mesh along an
@@ -315,10 +315,10 @@ def sweep_polygon(
 def extrude_triangulation(
     vertices: ArrayLike,
     faces: ArrayLike,
-    height: float,
-    transform: Optional[NDArray] = None,
+    height: Number,
+    transform: Optional[ArrayLike] = None,
     **kwargs,
-):
+) -> Trimesh:
     """
     Extrude a 2D triangulation into a watertight mesh.
 
@@ -404,10 +404,13 @@ def extrude_triangulation(
     return mesh
 
 
-def triangulate_polygon(polygon: Polygon, triangle_args=None, engine=None, **kwargs):
+def triangulate_polygon(
+    polygon, triangle_args: Optional[str] = None, engine: Optional[str] = None, **kwargs
+):
     """
     Given a shapely polygon create a triangulation using a
-    python interface to `triangle.c` or mapbox-earcut.
+    python interface to the permissively licensed `mapbox-earcut`
+    or the more robust `triangle.c`.
     > pip install triangle
     > pip install mapbox_earcut
 
@@ -416,9 +419,9 @@ def triangulate_polygon(polygon: Polygon, triangle_args=None, engine=None, **kwa
     polygon : Shapely.geometry.Polygon
         Polygon object to be triangulated.
     triangle_args : str or None
-        Passed to triangle.triangulate i.e: 'p', 'pq30'
+        Passed to triangle.triangulate i.e: 'p', 'pq30', 'pY'="don't insert vert"
     engine : None or str
-      Any value other than 'earcut' will use `triangle`
+      None or 'earcut' will use earcut, 'triangle' will use triangle
 
     Returns
     --------------
@@ -467,7 +470,7 @@ def triangulate_polygon(polygon: Polygon, triangle_args=None, engine=None, **kwa
         raise ValueError("no valid triangulation engine!")
 
 
-def _polygon_to_kwargs(polygon: Polygon) -> Dict:
+def _polygon_to_kwargs(polygon) -> Dict:
     """
     Given a shapely polygon generate the data to pass to
     the triangle mesh generator
@@ -559,13 +562,18 @@ def _polygon_to_kwargs(polygon: Polygon) -> Dict:
     return result
 
 
-def box(extents=None, transform: Optional[NDArray] = None, bounds=None, **kwargs):
+def box(
+    extents: Optional[ArrayLike] = None,
+    transform: Optional[ArrayLike] = None,
+    bounds: Optional[ArrayLike] = None,
+    **kwargs,
+):
     """
     Return a cuboid.
 
     Parameters
     ------------
-    extents : float, or (3,) float
+    extents : (3,) float
       Edge lengths
     transform: (4, 4) float
       Transformation matrix
@@ -703,7 +711,7 @@ def box(extents=None, transform: Optional[NDArray] = None, bounds=None, **kwargs
     return box
 
 
-def icosahedron(**kwargs):
+def icosahedron(**kwargs) -> Trimesh:
     """
     Create an icosahedron, one of the platonic solids which is has 20 faces.
 
@@ -827,7 +835,7 @@ def icosahedron(**kwargs):
     )
 
 
-def icosphere(subdivisions: int = 3, radius: float = 1.0, **kwargs):
+def icosphere(subdivisions: Integer = 3, radius: Number = 1.0, **kwargs):
     """
     Create an isophere centered at the origin.
 
@@ -847,9 +855,12 @@ def icosphere(subdivisions: int = 3, radius: float = 1.0, **kwargs):
     ico : trimesh.Trimesh
       Meshed sphere
     """
+    radius = float(radius)
+    subdivisions = int(subdivisions)
 
     ico = icosahedron()
     ico._validate = False
+
     for _ in range(subdivisions):
         ico = ico.subdivide()
         vectors = ico.vertices
@@ -857,6 +868,13 @@ def icosphere(subdivisions: int = 3, radius: float = 1.0, **kwargs):
         unit = vectors / scalar.reshape((-1, 1))
         ico.vertices += unit * (radius - scalar).reshape((-1, 1))
 
+    # if we didn't subdivide we still need to refine the radius
+    if subdivisions <= 0:
+        vectors = ico.vertices
+        scalar = np.sqrt(np.dot(vectors**2, [1, 1, 1]))
+        unit = vectors / scalar.reshape((-1, 1))
+        ico.vertices += unit * (radius - scalar).reshape((-1, 1))
+
     if "color" in kwargs:
         warnings.warn(
             "`icosphere(color=...)` is deprecated and will "
@@ -877,11 +895,11 @@ def icosphere(subdivisions: int = 3, radius: float = 1.0, **kwargs):
 
 
 def uv_sphere(
-    radius: float = 1.0,
+    radius: Number = 1.0,
     count: Optional[ArrayLike] = None,
-    transform: Optional[NDArray] = None,
+    transform: Optional[ArrayLike] = None,
     **kwargs,
-):
+) -> Trimesh:
     """
     Create a UV sphere (latitude + longitude) centered at the
     origin. Roughly one order of magnitude faster than an
@@ -926,10 +944,10 @@ def uv_sphere(
 
 
 def capsule(
-    height: float = 1.0,
-    radius: float = 1.0,
+    height: Number = 1.0,
+    radius: Number = 1.0,
     count: Optional[ArrayLike] = None,
-    transform: Optional[NDArray] = None,
+    transform: Optional[ArrayLike] = None,
 ):
     """
     Create a mesh of a capsule, or a cylinder with hemispheric ends.
@@ -979,12 +997,12 @@ def capsule(
 
 
 def cone(
-    radius: float,
-    height: float,
-    sections: Optional[int] = None,
-    transform: Optional[NDArray] = None,
+    radius: Number,
+    height: Number,
+    sections: Optional[Integer] = None,
+    transform: Optional[ArrayLike] = None,
     **kwargs,
-):
+) -> Trimesh:
     """
     Create a mesh of a cone along Z centered at the origin.
 
@@ -1020,11 +1038,11 @@ def cone(
 
 
 def cylinder(
-    radius: float,
-    height: Optional[float] = None,
-    sections: Optional[int] = None,
-    segment=None,
-    transform: Optional[NDArray] = None,
+    radius: Number,
+    height: Optional[Number] = None,
+    sections: Optional[Integer] = None,
+    segment: Optional[ArrayLike] = None,
+    transform: Optional[ArrayLike] = None,
     **kwargs,
 ):
     """
@@ -1071,12 +1089,12 @@ def cylinder(
 
 
 def annulus(
-    r_min: float,
-    r_max: float,
-    height: Optional[float] = None,
-    sections: Optional[int] = None,
-    transform: Optional[NDArray] = None,
-    segment: Optional[NDArray] = None,
+    r_min: Number,
+    r_max: Number,
+    height: Optional[Number] = None,
+    sections: Optional[Integer] = None,
+    transform: Optional[ArrayLike] = None,
+    segment: Optional[ArrayLike] = None,
     **kwargs,
 ):
     """
@@ -1143,7 +1161,7 @@ def annulus(
     return annulus
 
 
-def _segment_to_cylinder(segment: NDArray[float64]):
+def _segment_to_cylinder(segment: ArrayLike):
     """
     Convert a line segment to a transform and height for a cylinder
     or cylinder-like primitive.
@@ -1177,7 +1195,7 @@ def _segment_to_cylinder(segment: NDArray[float64]):
     return transform, height
 
 
-def random_soup(face_count: int = 100):
+def random_soup(face_count: Integer = 100):
     """
     Return random triangles as a Trimesh
 
@@ -1198,11 +1216,11 @@ def random_soup(face_count: int = 100):
 
 
 def axis(
-    origin_size: float = 0.04,
-    transform: Optional[NDArray] = None,
+    origin_size: Number = 0.04,
+    transform: Optional[ArrayLike] = None,
     origin_color: Optional[ArrayLike] = None,
-    axis_radius: Optional[float] = None,
-    axis_length: Optional[float] = None,
+    axis_radius: Optional[Number] = None,
+    axis_length: Optional[Number] = None,
 ):
     """
     Return an XYZ axis marker as a  Trimesh, which represents position
@@ -1284,7 +1302,7 @@ def axis(
 
 
 def camera_marker(
-    camera, marker_height: float = 0.4, origin_size: Optional[float] = None
+    camera, marker_height: Number = 0.4, origin_size: Optional[Number] = None
 ):
     """
     Create a visual marker for a camera object, including an axis and FOV.
@@ -1411,11 +1429,11 @@ def truncated_prisms(
 
 
 def torus(
-    major_radius: float,
-    minor_radius: float,
-    major_sections: int = 32,
-    minor_sections: int = 32,
-    transform: Optional[NDArray] = None,
+    major_radius: Number,
+    minor_radius: Number,
+    major_sections: Integer = 32,
+    minor_sections: Integer = 32,
+    transform: Optional[ArrayLike] = None,
     **kwargs,
 ):
     """Create a mesh of a torus around Z centered at the origin.
