@@ -237,10 +237,8 @@ def is_sequence(obj) -> bool:
     is_sequence : bool
         True if object is sequence
     """
-    seq = (
-        not hasattr(obj, "strip")
-        and hasattr(obj, "__getitem__")
-        or hasattr(obj, "__iter__")
+    seq = (not hasattr(obj, "strip") and hasattr(obj, "__getitem__")) or hasattr(
+        obj, "__iter__"
     )
 
     # check to make sure it is not a set, string, or dictionary
@@ -1444,16 +1442,24 @@ def concatenate(a, b=None):
             flat.extend(b)
         else:
             flat.append(b)
+    dump = []
+    for i in flat:
+        if is_instance_named(i, "Scene"):
+            dump.extend(i.dump())
+        else:
+            dump.append(i)
 
-    if len(flat) == 1:
+    if len(dump) == 1:
         # if there is only one mesh just return the first
-        return flat[0].copy()
-    elif len(flat) == 0:
-        # if there are no meshes return an empty list
-        return []
+        return dump[0].copy()
+    elif len(dump) == 0:
+        # if there are no meshes return an empty mesh
+        from .base import Trimesh
 
-    is_mesh = [f for f in flat if is_instance_named(f, "Trimesh")]
-    is_path = [f for f in flat if is_instance_named(f, "Path")]
+        return Trimesh()
+
+    is_mesh = [f for f in dump if is_instance_named(f, "Trimesh")]
+    is_path = [f for f in dump if is_instance_named(f, "Path")]
 
     if len(is_path) > len(is_mesh):
         from .path.util import concatenate as concatenate_path
@@ -2107,7 +2113,7 @@ def write_encoded(file_obj, stuff, encoding="utf-8"):
 
 def unique_id(length=12):
     """
-    Generate a random alphanumeric unique identifier
+    Generate a random alphaNumber unique identifier
     using UUID logic.
 
     Parameters
@@ -2118,7 +2124,7 @@ def unique_id(length=12):
     Returns
     ------------
     unique : str
-      Unique alphanumeric identifier
+      Unique alphaNumber identifier
     """
     return uuid.UUID(int=random.getrandbits(128), version=4).hex[:length]
 
